@@ -1,7 +1,8 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 
 /**
- * \file stack.c  Which windows cover which other windows
+ * SECTION:stack
+ * @short_description: Which windows cover which other windows
  */
 
 /* 
@@ -340,7 +341,7 @@ get_standalone_layer (MetaWindow *window)
                  windows_on_different_monitor (window,
                                                window->display->expected_focus_window))))
         layer = META_LAYER_FULLSCREEN;
-      else if (window->wm_state_above)
+      else if (window->wm_state_above && !META_WINDOW_MAXIMIZED (window))
         layer = META_LAYER_TOP;
       else
         layer = META_LAYER_NORMAL;
@@ -799,6 +800,8 @@ apply_constraints (Constraint **constraints,
 }
 
 /**
+ * stack_do_window_deletions:
+ *
  * Go through "deleted" and take the matching windows
  * out of "windows".
  */
@@ -899,6 +902,8 @@ stack_do_window_additions (MetaStack *stack)
 }
 
 /**
+ * stack_do_relayer:
+ *
  * Update the layers that windows are in
  */
 static void
@@ -944,6 +949,8 @@ stack_do_relayer (MetaStack *stack)
 }
 
 /**
+ * stack_do_constrain:
+ *
  * Update stack_position and layer to reflect transiency
  * constraints
  */
@@ -976,6 +983,8 @@ stack_do_constrain (MetaStack *stack)
 }
 
 /**
+ * stack_do_resort:
+ *
  * Sort stack->sorted with layers having priority over stack_position.
  */
 static void
@@ -994,6 +1003,8 @@ stack_do_resort (MetaStack *stack)
 }
 
 /**
+ * stack_ensure_sorted:
+ *
  * Puts the stack into canonical form.
  *
  * Honour the removed and added lists of the stack, and then recalculate
@@ -1013,6 +1024,8 @@ stack_ensure_sorted (MetaStack *stack)
 }
 
 /**
+ * raise_window_relative_to_managed_windows:
+ *
  * This function is used to avoid raising a window above popup
  * menus and other such things.
  *
@@ -1113,6 +1126,8 @@ raise_window_relative_to_managed_windows (MetaScreen *screen,
 }
 
 /**
+ * stack_sync_to_server:
+ *
  * Order the windows on the X server to be the same as in our structure.
  * We do this using XRestackWindows if we don't know the previous order,
  * or XConfigureWindow on a few particular windows if we do and can figure
